@@ -168,7 +168,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for organizing media bookmarks",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_bookmarks_plugin_init,
                    NULL,
