@@ -110,7 +110,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin that gets simple-to-obtain metadata from the local filesystem",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_local_metadata_source_plugin_init,
                    NULL,
