@@ -297,7 +297,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin that creates sources from Lua plugins",
                    "Victor Toso",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://victortoso.com",
                    grl_lua_factory_plugin_init,
                    grl_lua_factory_plugin_deinit,
@@ -1255,8 +1255,6 @@ table_to_tags (lua_State *L)
     lua_pop (L, 1);
   }
 
-  lua_pop (L, 1);
-
   if (array->len == 0) {
     g_ptr_array_free (array, TRUE);
     return NULL;
