@@ -169,7 +169,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for browsing optical media",
                    "GNOME",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.gnome.org",
                    grl_optical_media_plugin_init,
                    NULL,
