@@ -107,6 +107,30 @@ set_favourite (TrackerSparqlCursor *cursor,
   grl_data_set_boolean (GRL_DATA (media), key, is_favourite);
 }
 
+static void
+set_genre (TrackerSparqlCursor *cursor,
+           gint                 column,
+           GrlMedia            *media,
+           GrlKeyID             key)
+{
+  /* Tracker concatenetes multiple genres with a comma (vorbis or flac files).
+     ID3 (mp3 files) does not support multiple genres. A usual workaround is
+     to use a delimiter character such as a semi-colon or slashes.
+   */
+  const gchar *str = tracker_sparql_cursor_get_string (cursor, column, NULL);
+  gchar **genres = g_strsplit_set (str, ",;/", -1);
+
+  if (genres) {
+    gint i = 0;
+    gchar *genre = genres[i];
+    while (genre != NULL) {
+      grl_media_add_genre (media, g_strstrip (genre));
+      genre = genres[++i];
+    }
+  }
+  g_strfreev (genres);
+}
+
 static void
 set_title_from_filename (TrackerSparqlCursor *cursor,
                          gint                 column,
@@ -285,6 +309,12 @@ grl_tracker_setup_key_mappings (void)
                       "nmm:artistName(nmm:composer(?urn))",
                       "audio");
 
+  insert_key_mapping_with_setter (GRL_METADATA_KEY_GENRE,
+                                  "nfo:genre",
+                                  "nfo:genre(?urn)",
+                                  "audio",
+                                  set_genre);
+
   insert_key_mapping (GRL_METADATA_KEY_SIZE,
                       NULL,
                       "nfo:fileSize(?urn)",
@@ -807,81 +837,6 @@ grl_tracker_build_grilo_media (const gchar   *rdf_type,
 
 /**/
 
-static gchar *
-get_tracker_volume_name (const gchar *uri,
-			 const gchar *datasource)
-{
-  gchar *source_name = NULL;
-  GVolumeMonitor *volume_monitor;
-  GList *mounts, *mount;
-  GFile *file;
-
-  if (uri != NULL && *uri != '\0') {
-    volume_monitor = g_volume_monitor_get ();
-    mounts = g_volume_monitor_get_mounts (volume_monitor);
-    file = g_file_new_for_uri (uri);
-
-    mount = mounts;
-    while (mount != NULL) {
-      GFile *m_file = g_mount_get_root (G_MOUNT (mount->data));
-
-      if (g_file_equal (m_file, file)) {
-        gchar *m_name = g_mount_get_name (G_MOUNT (mount->data));
-        g_object_unref (G_OBJECT (m_file));
-        source_name = g_strdup_printf (_("Removable — %s"), m_name);
-        g_free (m_name);
-        break;
-      }
-      g_object_unref (G_OBJECT (m_file));
-
-      mount = mount->next;
-    }
-    g_list_free_full (mounts, g_object_unref);
-    g_object_unref (G_OBJECT (file));
-    g_object_unref (G_OBJECT (volume_monitor));
-  } else {
-    source_name = g_strdup (_("Local files"));
-  }
-
-  return source_name;
-}
-
-static gchar *
-get_tracker_upnp_name (const gchar *datasource_name)
-{
-  return g_strdup_printf ("UPnP — %s", datasource_name);
-}
-
-gchar *
-grl_tracker_get_source_name (const gchar *rdf_type,
-                             const gchar *uri,
-                             const gchar *datasource,
-                             const gchar *datasource_name)
-{
-  gchar *source_name = NULL;
-  gchar **rdf_single_type;
-  gint i;
-
-  /* As rdf_type can be formed by several types, split them */
-  rdf_single_type = g_strsplit (rdf_type, ",", -1);
-  i = g_strv_length (rdf_single_type) - 1;
-
-  while (i >= 0) {
-    if (g_str_has_suffix (rdf_single_type[i], RDF_TYPE_VOLUME)) {
-      source_name = get_tracker_volume_name (uri, datasource);
-      break;
-    } else if (g_str_has_suffix (rdf_single_type[i], RDF_TYPE_UPNP)) {
-      source_name = get_tracker_upnp_name (datasource_name);
-      break;
-    }
-    i--;
-  }
-
-  g_strfreev (rdf_single_type);
-
-  return source_name;
-}
-
 const GList *
 grl_tracker_supported_keys (GrlSource *source)
 {
