@@ -301,7 +301,7 @@ GRL_PLUGIN_DEFINE (GRL_MAJOR,
                    "A plugin for searching multimedia content using Tracker",
                    "Igalia S.L.",
                    VERSION,
-                   "LGPL",
+                   "LGPL-2.1-or-later",
                    "http://www.igalia.com",
                    grl_tracker_plugin_init,
                    grl_tracker_plugin_deinit,
