@@ -21,6 +21,7 @@
  */
 
 #include "test_thetvdb_utils.h"
+#include <locale.h>
 #include <grilo.h>
 
 /* Returns whether it could find tvdb-id */
@@ -295,6 +296,8 @@ main (gint argc, gchar **argv)
 {
   gint result;
 
+  setlocale (LC_ALL, "");
+
   g_setenv ("GRL_PLUGIN_PATH", THETVDB_PLUGIN_PATH, TRUE);
   g_setenv ("GRL_PLUGIN_LIST", THETVDB_ID, TRUE);
   g_setenv ("GRL_NET_MOCKED", THETVDB_PLUGIN_TEST_DATA_PATH "config.ini", TRUE);
